# Contributing

Merlin is open source software, and we welcome contribution!

We follow a gitflow - like [this](http://www.dalescott.net/using-gitflow-with-githubs-fork-pull-model/).
To contribute, fork your own copy.
All changes are done via pull requests from your fork into the appropriate main repository branch.
Features and additions into `develop`, hot fixes into `master`.

### Squash
Before merging a pull request, please [squash your commits](https://github.com/LLNL/merlin/wiki/Squash-commits) down to a single concise commit message.

### More...
Complete developer documentation is [here](https://merlin.readthedocs.io/en/latest/merlin_developer.html).

